from cmd import Cmd

from boto3 import client


class S3Shell(Cmd):

    def __init__(self):
        super().__init__()
        self.conn = client('s3')
        self._wd = ''
        self.prompt = '> '

    @property
    def wd(self):
        return self._wd

    @wd.setter
    def wd(self, d):
        self.prompt = d + '> '
        self._wd = d

    def do_ls(self, args):

        if not self.wd and not args:
            [print(b.get('Name')) for b in self.conn.list_buckets().get('Buckets')]
        else:
            if args:
                bucket, *prefix = args.split('/')
            else:
                bucket, *prefix = self.wd.split('/')
            prefix = '/'.join(prefix)
            result = self.conn.list_objects(Bucket=bucket, Prefix=prefix, Delimiter='/')
            for o in result.get('CommonPrefixes'):
                print(o.get('Prefix').replace(prefix, ''))

    def do_cd(self, args):
        if args == '..':
            self.wd = '/'.join(self.wd.split('/')[:-2])
        else:
            self.wd += args + '/'




#!/usr/bin/env python

from setuptools import setup, find_packages

setup(
    name='s3sh',
    version='0.1.5',
    description='A repl for s3',
    long_description='Traverse s3 just like it would be a filesystem',
    author='Wim Berchmans',
    author_email="wimberchmans@gmail.com",
    license='',
    url='https://github.com/WRRB/s3sh',
    include_package_data=True,
    package_data={},
    packages=find_packages(),
    install_requires=['boto3'],
    tests_require=[],
    scripts=['trail/cli/trail', 'trail/cli/trail.bat'],
    zip_safe=False
)
